﻿' EXAMPLE - SQL08 for Visual Basic using ADO.NET
' This example shows how to use transactions with SQL commands.  A database
' is created and then data is inserted within a transaction, which is
' committed and then the data is read out and displayed.
' 
' The following methods are illustrated:
'     Raima.Rdm.RdmConnection:
'         BeginTransaction() Method
'         ChangeDatabase(string) Method
'         Close() Method
'         CreateCommand() Method
'         Open() Method
'         RdmConnection() Constructor
'     Raima.Rdm.RdmCommand:
'         CommandText Property
'         ExecuteNonQuery() Method
'         ExecuteReader() Method
'     Raima.Rdm.RdmDataReader:
'         Item[int] Property
'         Read() Method
'     Raima.Rdm.RdmTransaction
'         Commit() Method
' 
' They are fully document in http://docs.raima.com/rdm/.
' 
' For simplicity this example does not catch any thrown execptions
' but good programming practices would dictate that this occur in
' a full application.

' Raima.Rdm is the system module that contains the ADO.NET
' data provider for RDM
Imports Rdm = Raima.Rdm

Module SQL08
    Sub DropDatabase(conn As Rdm.RdmConnection, name As String)
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        ' Attempt to drop this database.  If the database does not already
        ' exist this will fail and we simply ignore the failure for this
        ' sample.
        Try
            cmd.CommandText = "DROP DATABASE " + name
            cmd.ExecuteNonQuery()
        Catch ex As Exception
        End Try

    End Sub

    Sub CreateThisDatabase(conn As Rdm.RdmConnection, name As String, cmds() As String)
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        cmd.CommandText = "CREATE DATABASE " + name
        cmd.ExecuteNonQuery()

        For Each c In cmds
            cmd.CommandText = c
            cmd.ExecuteNonQuery()
        Next

        cmd.CommandText = "COMMIT"
        cmd.ExecuteNonQuery()

        cmd.CommandText = "CLOSE " + name
        cmd.ExecuteNonQuery()
    End Sub

    Sub CreateDatabases(conn As Rdm.RdmConnection)
        ' Drop any existing copy of the databases.
        DropDatabase(conn, "SQL08")

        ' Attempt to create the database
        Dim cmds(0) As String
        cmds(0) = "CREATE TABLE Table1 (id INTEGER PRIMARY KEY)"
        CreateThisDatabase(conn, "SQL08", cmds)
    End Sub

    Sub Main()
        ' Create the connection with a simple connection string
        Dim conn As Rdm.RdmConnection
        conn = New Rdm.RdmConnection("host=local;openmode=x")
        conn.Open()

        CreateDatabases(conn)

        ' Open the database
        conn.ChangeDatabase("SQL08")

        ' Start a new transaction
        Dim trans As Rdm.RdmTransaction
        trans = conn.BeginTransaction()

        ' Create a new command
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        ' Insert three rows into the table
        For ii = 1 To 3
            cmd.CommandText = "INSERT INTO Table1 VALUES " + Convert.ToString(ii)
            cmd.ExecuteNonQuery()
        Next

        ' Commit the transaction
        trans.Commit()

        ' Scan through the data, displaying the rows
        cmd.CommandText = "SELECT id FROM Table1"
        Dim reader As Rdm.RdmDataReader
        reader = cmd.ExecuteReader()

        While (reader.Read())
            Console.WriteLine(Convert.ToString(reader.Item(0)))
        End While

        conn.Close()

        Console.WriteLine("Hit <Enter> to continue")
        Console.ReadLine()
    End Sub
End Module
